@@ -213,7 +213,11 @@ class FinXRest:
         return years_to_expiry
 
     def _parse_strike_price(self, row):
-        return row['instrument_name'].split("-")[2]
+        try:
+            strike_price = float(row['instrument_name'].split("-")[2])
+        except:
+            strike_price = -1
+        return strike_price
 
     @Hybrid
     async def prepare_vol_surface_inputs(self, filename, timeslice_datestamp, timeslice_width_seconds, underlying_symbol) -> str:
